=========
Changelog
=========
All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_.

----------------------
`0.1.0`_ - 2021-11-07
----------------------
- Initial release

.. _0.1.0: https://github.com/mkdryden/obs-websocket-py-trio/releases/tag/v0.1.1
